@@ -14,6 +14,7 @@
 #' versus the `.value`. Useful for evaluating external lagged regressors.
 #' @param .lags A sequence of one or more lags to evaluate.
 #' @param .show_ccf_vars_only Hides the ACF and PACF plots so you can focus on only CCFs.
+#' @param .show_white_noise_bars Shows the white noise significance bounds.
 #' @param .facet_ncol Facets: Number of facet columns. Has no effect if using `grouped_df`.
 #' @param .facet_scales Facets: Options include "fixed", "free", "free_y", "free_x"
 #' @param .line_color Line color. Use keyword: "scale_color" to change the color by the facet.
@@ -25,6 +26,9 @@
 #' @param .x_intercept Numeric lag. Adds a vertical line.
 #' @param .x_intercept_color Color for the x-intercept line.
 #' @param .hline_color Color for the y-intercept = 0 line.
+#' @param .white_noise_line_type Line type for white noise bars. Set to 2 for "dashed" by default.
+#' @param .white_noise_line_color Line color for white noise bars.
+#'  Set to `tidyquant::palette_light()` "steel blue" by default.
 #' @param .title Title for the plot
 #' @param .x_lab X-axis label for the plot
 #' @param .y_lab Y-axis label for the plot
@@ -67,6 +71,12 @@
 #' Unlike other plotting utilities, the `.facet_vars` arguments is NOT included.
 #' Use `dplyr::group_by()` for processing multiple time series groups.
 #'
+#' __Calculating the White Noise Significance Bars__
+#'
+#' The formula for the significance bars is `+2/sqrt(T)` and `-2/sqrt(T)` where `T` is the length of the
+#' time series. For a white noise time series, 95% of the data points should fall
+#' within this range. Those that don't may be significant autocorrelations.
+#'
 #' @seealso
 #' - __Visualizing ACF, PACF, & CCF:__ [plot_acf_diagnostics()]
 #' - __Visualizing Seasonality:__ [plot_seasonal_diagnostics()]
@@ -113,6 +123,7 @@
 #' @export
 plot_acf_diagnostics <- function(.data, .date_var, .value, .ccf_vars = NULL, .lags = 1000,
                                  .show_ccf_vars_only = FALSE,
+                                 .show_white_noise_bars = FALSE,
                                  .facet_ncol = 1, .facet_scales = "fixed",
                                  .line_color = "#2c3e50", .line_size = 0.5,
                                  .line_alpha = 1,
@@ -121,6 +132,8 @@ plot_acf_diagnostics <- function(.data, .date_var, .value, .ccf_vars = NULL, .la
                                  .x_intercept = NULL,
                                  .x_intercept_color = "#E31A1C",
                                  .hline_color = "#2c3e50",
+                                 .white_noise_line_type = 2,
+                                 .white_noise_line_color = "#A6CEE3",
                                  .title = "Lag Diagnostics",
                                  .x_lab = "Lag", .y_lab = "Correlation",
                                  .interactive = TRUE, .plotly_slider = FALSE) {
@@ -140,6 +153,7 @@ plot_acf_diagnostics <- function(.data, .date_var, .value, .ccf_vars = NULL, .la
 #' @export
 plot_acf_diagnostics.data.frame <- function(.data, .date_var, .value, .ccf_vars = NULL, .lags = 1000,
                                             .show_ccf_vars_only = FALSE,
+                                            .show_white_noise_bars = FALSE,
                                             .facet_ncol = 1, .facet_scales = "fixed",
                                             .line_color = "#2c3e50", .line_size = 0.5,
                                             .line_alpha = 1,
@@ -148,6 +162,8 @@ plot_acf_diagnostics.data.frame <- function(.data, .date_var, .value, .ccf_vars
                                             .x_intercept = NULL,
                                             .x_intercept_color = "#E31A1C",
                                             .hline_color = "#2c3e50",
+                                            .white_noise_line_type = 2,
+                                            .white_noise_line_color = "#A6CEE3",
                                             .title = "Lag Diagnostics",
                                             .x_lab = "Lag", .y_lab = "Correlation",
                                             .interactive = TRUE, .plotly_slider = FALSE) {
@@ -172,10 +188,13 @@ plot_acf_diagnostics.data.frame <- function(.data, .date_var, .value, .ccf_vars
     }
 
     data_formatted <- data_formatted %>%
-        tidyr::pivot_longer(cols = -lag, values_to = "value", names_to = "name") %>%
+        tidyr::pivot_longer(cols = -c(lag, .white_noise_upper, .white_noise_lower),
+                            values_to = "value", names_to = "name") %>%
         dplyr::mutate(name = forcats::as_factor(name))
 
 
+    # time_series_length <- nrow(.data)
+
 
     # ---- VISUALIZATION ----
 
@@ -213,6 +232,17 @@ plot_acf_diagnostics.data.frame <- function(.data, .date_var, .value, .ccf_vars
             ggplot2::geom_point(color = .point_color, size = .point_size, alpha = .point_alpha)
     }
 
+    # Add white noise bars
+    if (.show_white_noise_bars) {
+        g <- g +
+            ggplot2::geom_line(ggplot2::aes(y = .white_noise_upper),
+                               linetype = .white_noise_line_type,
+                               color    = .white_noise_line_color) +
+            ggplot2::geom_line(ggplot2::aes(y = .white_noise_lower),
+                               linetype = .white_noise_line_type,
+                               color    = .white_noise_line_color)
+    }
+
     # Add theme
     g <- g + theme_tq()
 
@@ -237,6 +267,7 @@ plot_acf_diagnostics.data.frame <- function(.data, .date_var, .value, .ccf_vars
 #' @export
 plot_acf_diagnostics.grouped_df <- function(.data, .date_var, .value, .ccf_vars = NULL, .lags = 1000,
                                             .show_ccf_vars_only = FALSE,
+                                            .show_white_noise_bars = FALSE,
                                             .facet_ncol = 1, .facet_scales = "fixed",
                                             .line_color = "#2c3e50", .line_size = 0.5,
                                             .line_alpha = 1,
@@ -245,6 +276,8 @@ plot_acf_diagnostics.grouped_df <- function(.data, .date_var, .value, .ccf_vars
                                             .x_intercept = NULL,
                                             .x_intercept_color = "#E31A1C",
                                             .hline_color = "#2c3e50",
+                                            .white_noise_line_type = 2,
+                                            .white_noise_line_color = "#A6CEE3",
                                             .title = "Lag Diagnostics",
                                             .x_lab = "Lag", .y_lab = "Correlation",
                                             .interactive = TRUE, .plotly_slider = FALSE) {
@@ -276,13 +309,11 @@ plot_acf_diagnostics.grouped_df <- function(.data, .date_var, .value, .ccf_vars
         dplyr::mutate(.groups_consolidated = forcats::as_factor(.groups_consolidated)) %>%
         dplyr::select(-(!!! rlang::syms(group_names))) %>%
         dplyr::select(.groups_consolidated, lag, dplyr::everything()) %>%
-        tidyr::pivot_longer(cols      = -c(.groups_consolidated, lag),
+        tidyr::pivot_longer(cols      = -c(.groups_consolidated, lag, .white_noise_upper, .white_noise_lower),
                             values_to = "value",
                             names_to  = "name") %>%
         dplyr::mutate(name = forcats::as_factor(name))
 
-
-
     # data_formatted
 
     g <- data_formatted %>%
@@ -321,6 +352,17 @@ plot_acf_diagnostics.grouped_df <- function(.data, .date_var, .value, .ccf_vars
             ggplot2::geom_point(color = .point_color, size = .point_size, alpha = .point_alpha)
     }
 
+    # Add white noise bars
+    if (.show_white_noise_bars) {
+        g <- g +
+            ggplot2::geom_line(ggplot2::aes(y = .white_noise_upper),
+                                linetype = .white_noise_line_type,
+                                color    = .white_noise_line_color) +
+            ggplot2::geom_line(ggplot2::aes(y = .white_noise_lower),
+                                linetype = .white_noise_line_type,
+                                color    = .white_noise_line_color)
+    }
+
     # Add theme
     g <- g + theme_tq()
 
